@extends($activeTemplate . 'layouts.master')
@section('content')
    <section class="pt-100 pb-100 bg-light">
        <div class="container">
            <div class="row justify-content-center mt-4">
                <div class="col-md-10">
                    <div class="custom--card">
                        <div class="card-header">
                            <h5 class="card-title text-center">{{ __($pageTitle) }}</h5>
                        </div>
                        <div class="card-body">
                            <form class="transparent-form" action="{{ route('ticket.store') }}" method="post"
                                enctype="multipart/form-data" onsubmit="return submitUserForm();">
                                @csrf
                                <div class="row">
                                    <div class="form-group col-md-6 mb-3">
                                        <label for="name" class="form-label">@lang('Name')</label>
                                        <input type="text" name="name"
                                            value="{{ @$user->firstname . ' ' . @$user->lastname }}"
                                            class="form--control form-control" readonly>
                                    </div>
                                    <div class="form-group col-md-6 mb-3">
                                        <label for="email" class="form-label">@lang('Email address')</label>
                                        <input type="email" name="email" value="{{ @$user->email }}"
                                            class="form--control form-control"readonly>
                                    </div>

                                    <div class="form-group col-md-6 mb-3">
                                        <label for="website" class="form-label">@lang('Subject')</label>
                                        <input type="text" name="subject" value="{{ old('subject') }}"
                                            class="form--control form-control" required>
                                    </div>
                                    <div class="form-group col-md-6 mb-3">
                                        <label for="priority" class="form-label">@lang('Priority')</label>
                                        <select name="priority" class="form--control form-control form-select">
                                            <option value="3">@lang('High')</option>
                                            <option value="2">@lang('Medium')</option>
                                            <option value="1">@lang('Low')</option>
                                        </select>
                                    </div>
                                    <div class="col-12 form-group">
                                        <label for="inputMessage" class="form-label">@lang('Message')</label>
                                        <textarea name="message" id="inputMessage" rows="6" class="form--control form-control" required>{{ old('message') }}</textarea>
                                    </div>
                                </div>

                                <div class="col-md-9 form-group">
                                    <button type="button" class="btn btn--base btn-sm addAttachment my-2"> <i
                                            class="fas fa-plus"></i> @lang('Add Attachment') </button>
                                    <p class="mb-2"><span class="text--info">@lang('Max 5 files can be uploaded | Maximum upload size is ' . convertToReadableSize(ini_get('upload_max_filesize')) . ' | Allowed File Extensions: .jpg, .jpeg, .png, .pdf, .doc, .docx')</span></p>
                                    <div class="row fileUploadsContainer gy-4 mb-4">
                                    </div>
                                </div>

                                <div class="row form-group justify-content-center">
                                    <div class="col-md-12">
                                        <button class="btn btn--base w-100 text-center" type="submit"
                                            id="recaptcha">@lang('Submit')</button>
                                    </div>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
@endsection

@push('style-lib')
    <link rel="stylesheet" href="{{ asset('assets/global/css/select2.min.css') }}">
@endpush

@push('script-lib')
    <script src="{{ asset('assets/global/js/select2.min.js') }}"></script>
@endpush



@push('style')
    <style>
        .input-group-text:focus {
            box-shadow: none !important;
        }
    </style>
@endpush

@push('script')
    <script>
        (function($) {
            "use strict";

            $('.select2').select2();
            var fileAdded = 0;

            $('.addAttachment').on('click', function() {
                fileAdded++;
                if (fileAdded == 5) {
                    $(this).attr('disabled', true)
                }
                $(".fileUploadsContainer").append(`
                    <div class="col-lg-6 col-md-12 form-group removeFileInput">
                        <div class="input-group">
                            <input type="file" name="attachments[]" class="form-control" accept=".jpeg,.jpg,.png,.pdf,.doc,.docx" required>
                            <button type="button" class="input-group-text removeFile bg--danger border--danger"><i class="fas fa-times"></i></button>
                        </div>
                    </div>
                `)
            });
            $(document).on('click', '.removeFile', function() {
                $('.addAttachment').removeAttr('disabled', true)
                fileAdded--;
                $(this).closest('.removeFileInput').remove();
            });


        })(jQuery);
    </script>
@endpush
